@@ -9,9 +9,21 @@ import (
 	"github.com/gobwas/glob"
 )
 
+// Commit is a commit with a hash, title (first line of the message), and body
+// (rest of the message, not including the title).
+type Commit struct {
+	SHA   string
+	Title string
+	Body  string
+}
+
+func (c Commit) String() string {
+	return c.SHA + ": " + c.Title + "\n" + c.Body
+}
+
 const (
-	AllBranchesTagMode   = "all-branches"
-	CurrentBranchTagMode = "current-branch"
+	TagModeAll     = "all"
+	TagModeCurrent = "current"
 )
 
 // copied from goreleaser
@@ -22,6 +34,11 @@ func IsRepo() bool {
 	return err == nil && strings.TrimSpace(out) == "true"
 }
 
+func Root() string {
+	out, _ := run("rev-parse", "--show-toplevel")
+	return strings.TrimSpace(out)
+}
+
 func getAllTags(args ...string) ([]string, error) {
 	tags, err := run(append([]string{"-c", "versionsort.suffix=-", "tag", "--sort=-version:refname"}, args...)...)
 	if err != nil {
@@ -32,7 +49,7 @@ func getAllTags(args ...string) ([]string, error) {
 
 func DescribeTag(tagMode string, pattern string) (string, error) {
 	args := []string{}
-	if tagMode == CurrentBranchTagMode {
+	if tagMode == TagModeCurrent {
 		args = []string{"--merged"}
 	}
 	tags, err := getAllTags(args...)
@@ -59,11 +76,11 @@ func DescribeTag(tagMode string, pattern string) (string, error) {
 	return "", fmt.Errorf("no tags match '%s'", pattern)
 }
 
-func Changelog(tag string, dir string) (string, error) {
+func Changelog(tag string, dirs []string) ([]Commit, error) {
 	if tag == "" {
-		return gitLog(dir, "HEAD")
+		return gitLog(dirs, "HEAD")
 	} else {
-		return gitLog(dir, fmt.Sprintf("tags/%s..HEAD", tag))
+		return gitLog(dirs, fmt.Sprintf("tags/%s..HEAD", tag))
 	}
 }
 
@@ -81,11 +98,35 @@ func run(args ...string) (string, error) {
 	return string(bts), nil
 }
 
-func gitLog(dir string, refs ...string) (string, error) {
-	args := []string{"log", "--no-decorate", "--no-color"}
+func gitLog(dirs []string, refs ...string) ([]Commit, error) {
+	args := []string{"log", "--no-decorate", "--no-color", `--format=%H:%B<svu-commit-end>`}
 	args = append(args, refs...)
-	if dir != "" {
-		args = append(args, "--", dir)
+	if len(dirs) > 0 {
+		args = append(args, "--")
+		args = append(args, dirs...)
 	}
-	return run(args...)
+	s, err := run(args...)
+	if err != nil {
+		return nil, err
+	}
+	var result []Commit
+	for _, commit := range strings.Split(s, "<svu-commit-end>") {
+		commit = strings.TrimSpace(commit)
+		if commit == "" { // accounts for the last split, which will be an empty line
+			continue
+		}
+
+		hashEndIdx := strings.Index(commit, ":")
+		titleEndIdx := strings.Index(commit, "\n")
+		if titleEndIdx < 0 {
+			titleEndIdx = len(commit)
+		}
+
+		result = append(result, Commit{
+			commit[:hashEndIdx],
+			commit[hashEndIdx+1 : titleEndIdx],
+			commit[min(titleEndIdx+1, len(commit)):],
+		})
+	}
+	return result, nil
 }
