@@ -3,25 +3,22 @@ package git
 import (
 	"os"
 	"path"
-	"strings"
 	"testing"
 	"time"
 
-	"github.com/matryer/is"
+	"github.com/stretchr/testify/require"
 )
 
 func TestIsRepo(t *testing.T) {
 	t.Run("is not a repo", func(t *testing.T) {
 		tempdir(t)
-		is := is.New(t)
-		is.Equal(false, IsRepo()) // should not be arepo
+		require.False(t, IsRepo()) // should not be arepo
 	})
 
 	t.Run("is a repo", func(t *testing.T) {
 		tempdir(t)
 		gitInit(t)
-		is := is.New(t)
-		is.True(IsRepo()) // should be arepo
+		require.True(t, IsRepo()) // should be arepo
 	})
 }
 
@@ -46,28 +43,25 @@ func TestDescribeTag(t *testing.T) {
 		gitTag(tb, "v1.2.5-prerelease")
 		switchToBranch(tb, "-")
 	}
-	t.Run("normal", func(t *testing.T) {
+	t.Run(TagModeCurrent, func(t *testing.T) {
 		setup(t)
-		is := is.New(t)
-		tag, err := DescribeTag("current-branch", "")
-		is.NoErr(err)
-		is.Equal("v1.2.4", tag)
+		tag, err := DescribeTag(TagModeCurrent, "")
+		require.NoError(t, err)
+		require.Equal(t, "v1.2.4", tag)
 	})
 
-	t.Run("all-branches", func(t *testing.T) {
+	t.Run(TagModeAll, func(t *testing.T) {
 		setup(t)
-		is := is.New(t)
-		tag, err := DescribeTag("all-branches", "")
-		is.NoErr(err)
-		is.Equal("v1.2.5", tag)
+		tag, err := DescribeTag(TagModeAll, "")
+		require.NoError(t, err)
+		require.Equal(t, "v1.2.5", tag)
 	})
 
 	t.Run("pattern", func(t *testing.T) {
 		setup(t)
-		is := is.New(t)
-		tag, err := DescribeTag("current-branch", "pattern-*")
-		is.NoErr(err)
-		is.Equal("pattern-1.2.3", tag)
+		tag, err := DescribeTag(TagModeCurrent, "pattern-*")
+		require.NoError(t, err)
+		require.Equal(t, "pattern-1.2.3", tag)
 	})
 }
 
@@ -84,15 +78,33 @@ func TestChangelog(t *testing.T) {
 	} {
 		gitCommit(t, msg)
 	}
-	is := is.New(t)
-	log, err := Changelog("v1.2.3", "")
-	is.NoErr(err)
-	for _, msg := range []string{
+	log, err := Changelog("v1.2.3", nil)
+	require.NoError(t, err)
+	for _, title := range []string{
 		"chore: foobar",
 		"fix: foo",
 		"feat: foobar",
 	} {
-		is.True(strings.Contains(log, msg)) // log should contain commit
+		requireLogContains(t, log, title)
+	}
+}
+
+func requireLogContains(tb testing.TB, log []Commit, title string) {
+	tb.Helper()
+	for _, commit := range log {
+		if commit.Title == title {
+			return
+		}
+	}
+	tb.Errorf("expected %v to contain a commit with msg %q", log, title)
+}
+
+func requireLogNotContains(tb testing.TB, log []Commit, title string) {
+	tb.Helper()
+	for _, commit := range log {
+		if commit.Title == title {
+			tb.Errorf("expected %v to not contain a commit with msg %q", log, title)
+		}
 	}
 }
 
@@ -107,77 +119,67 @@ func TestChangelogWithDirectory(t *testing.T) {
 	gitCommit(t, "feat: foobar")
 	gitAdd(t, file)
 	gitCommit(t, "chore: filtered dir")
-	is := is.New(t)
-	log, err := Changelog("v1.2.3", localDir)
-	is.NoErr(err)
+	log, err := Changelog("v1.2.3", []string{localDir})
+	require.NoError(t, err)
 
-	is.True(strings.Contains(log, "chore: filtered dir"))
-	is.True(!strings.Contains(log, "feat: foobar"))
+	requireLogContains(t, log, "chore: filtered dir")
+	requireLogNotContains(t, log, "feat: foobar")
 }
 
 func switchToBranch(tb testing.TB, branch string) {
-	is := is.New(tb)
 	_, err := fakeGitRun("switch", branch)
-	is.NoErr(err)
+	require.NoError(tb, err)
 }
 
 func createBranch(tb testing.TB, branch string) {
-	is := is.New(tb)
 	_, err := fakeGitRun("switch", "-c", branch)
-	is.NoErr(err)
+	require.NoError(tb, err)
 }
 
 func gitTag(tb testing.TB, tag string) {
-	is := is.New(tb)
 	_, err := fakeGitRun("tag", tag)
-	is.NoErr(err)
+	require.NoError(tb, err)
 }
 
 func gitCommit(tb testing.TB, msg string) {
-	is := is.New(tb)
 	_, err := fakeGitRun("commit", "--allow-empty", "-am", msg)
-	is.NoErr(err)
+	require.NoError(tb, err)
 }
 
 func gitAdd(tb testing.TB, path string) {
-	is := is.New(tb)
 	_, err := fakeGitRun("add", path)
-	is.NoErr(err)
+	require.NoError(tb, err)
 }
 
 func gitInit(tb testing.TB) {
-	is := is.New(tb)
 	_, err := fakeGitRun("init")
-	is.NoErr(err)
+	require.NoError(tb, err)
 }
 
 func tempdir(tb testing.TB) string {
-	is := is.New(tb)
 	previous, err := os.Getwd()
-	is.NoErr(err)
+	require.NoError(tb, err)
 	tb.Cleanup(func() {
-		is.NoErr(os.Chdir(previous))
+		require.NoError(tb, os.Chdir(previous))
 	})
 	dir := tb.TempDir()
-	is.NoErr(os.Chdir(dir))
+	require.NoError(tb, os.Chdir(dir))
 	tb.Logf("cd into %s", dir)
 	return dir
 }
 
 func dir(tempDir string, tb testing.TB) string {
-	is := is.New(tb)
 	createdDir := path.Join(tempDir, "a-folder")
-	err := os.Mkdir(createdDir, 0755)
-	is.NoErr(err)
+	err := os.Mkdir(createdDir, 0o755)
+	require.NoError(tb, err)
 	return createdDir
 }
 
 func tempfile(tb testing.TB, dir string) string {
-	is := is.New(tb)
 	d1 := []byte("hello\ngo\n")
 	file := path.Join(dir, "a-file.txt")
-	err := os.WriteFile(file, d1, 0644)
-	is.NoErr(err)
+	err := os.WriteFile(file, d1, 0o644)
+	require.NoError(tb, err)
 	return file
 }
 
