@@ -6,6 +6,7 @@ import (
 	"io"
 	"log"
 	"os"
+	"strings"
 
 	goversion "github.com/caarlos0/go-version"
 	"github.com/caarlos0/svu/v3/internal/git"
@@ -15,6 +16,12 @@ import (
 	"github.com/spf13/viper"
 )
 
+//go:embed description.txt
+var description []byte
+
+//go:embed examples.sh
+var examples []byte
+
 func main() {
 	var verbose bool
 	var opts svu.Options
@@ -30,9 +37,10 @@ func main() {
 
 	rootCmd := &cobra.Command{
 		Use:          "svu",
-		Short:        "semantic version util",
-		Long:         "semantic version util (svu) is a small helper for release scripts and workflows.\nIt provides utility commands to increase specific portions of the version.\nIt can also figure the next version out automatically by looking through the git history.",
+		Short:        "Semantic Version Utility",
+		Long:         string(description),
 		Version:      buildVersion(version, commit, date, builtBy).String(),
+		Example:      paddingLeft(string(examples)),
 		SilenceUsage: true,
 		PersistentPreRunE: func(*cobra.Command, []string) error {
 			switch opts.TagMode {
@@ -118,28 +126,34 @@ func main() {
 	}
 
 	rootCmd.SetVersionTemplate("{{.Version}}")
-
 	rootCmd.PersistentFlags().BoolVar(&verbose, "verbose", false, "enable logs")
-	rootCmd.PersistentFlags().StringVar(&opts.Pattern, "tag.pattern", "", "ignore tags that do not match the given pattern")
-	rootCmd.PersistentFlags().StringVar(&opts.Prefix, "tag.prefix", "v", "sets a tag custom prefix")
-	rootCmd.PersistentFlags().StringVar(&opts.TagMode, "tag.mode", git.TagModeAll, "determine if it should look for tags in all branches, or just the current one")
-
-	nextCmd.Flags().StringSliceVar(&opts.Directories, "log.directory", nil, "only use commits that changed files in the given directories")
-	nextCmd.Flags().StringVar(&opts.Metadata, "metadata", "", "sets the version metadata")
-	nextCmd.Flags().StringVar(&opts.PreRelease, "prerelease", "", "sets the version prerelease")
-	prereleaseCmd.Flags().StringVar(&opts.PreRelease, "prerelease", "", "sets the version prerelease")
+	rootCmd.AddCommand(initCmd)
 	nextCmd.Flags().BoolVar(&opts.Always, "always", false, "if no commits trigger a version change, increment the patch")
 	nextCmd.Flags().BoolVar(&opts.KeepV0, "v0", false, "prevent major version increments if current version is still v0")
 
-	rootCmd.AddCommand(
+	for _, cmd := range []*cobra.Command{
 		nextCmd,
 		majorCmd,
 		minorCmd,
 		patchCmd,
 		currentCmd,
 		prereleaseCmd,
-		initCmd,
-	)
+	} {
+		// init does not share these flags.
+		cmd.Flags().StringVar(&opts.Pattern, "tag.pattern", "", "ignore tags that do not match the given pattern")
+		cmd.Flags().StringVar(&opts.Prefix, "tag.prefix", "v", "sets a tag custom prefix")
+		cmd.Flags().StringVar(&opts.TagMode, "tag.mode", git.TagModeAll, "determine if it should look for tags in all branches, or just the current one")
+		cmd.Flags().StringVar(&opts.PreRelease, "prerelease", "", "sets the version prerelease")
+		cmd.Flags().StringVar(&opts.Metadata, "metadata", "", "sets the version metadata")
+		rootCmd.AddCommand(cmd)
+	}
+
+	for _, cmd := range []*cobra.Command{
+		nextCmd,
+		prereleaseCmd,
+	} {
+		cmd.Flags().StringSliceVar(&opts.Directories, "log.directory", nil, "only use commits that changed files in the given directories")
+	}
 
 	home, _ := os.UserHomeDir()
 	config, _ := os.UserConfigDir()
@@ -191,7 +205,7 @@ var exampleConfig []byte
 
 func buildVersion(version, commit, date, builtBy string) goversion.Info {
 	return goversion.GetVersionInfo(
-		goversion.WithAppDetails("svu", "Semantic Version Util", "https://github.com/caarlos0/svu"),
+		goversion.WithAppDetails("svu", "Semantic Version Utility", "https://github.com/caarlos0/svu"),
 		goversion.WithASCIIName(asciiArt),
 		func(i *goversion.Info) {
 			if commit != "" {
@@ -212,3 +226,11 @@ func buildVersion(version, commit, date, builtBy string) goversion.Info {
 		},
 	)
 }
+
+func paddingLeft(in string) string {
+	var out []string
+	for _, line := range strings.Split(in, "\n") {
+		out = append(out, "  "+line)
+	}
+	return strings.Join(out, "\n")
+}
